pub struct Deserializer<'a, 'de, P: Position, Reporter: diagReporter<P>> {
pub data: &'a Taml<'de, P>,
pub reporter: &'a mut Reporter,
pub encoders: &'a [(&'a str, &'a Encoder)],
}Expand description
A TAML Serde-Deserializer implementation.
Fields
data: &'a Taml<'de, P>The parsed TAML tree to deserialize further.
reporter: &'a mut ReporterA reporter for human-readable diagnostics.
Diagnostic output is not versioned! You can skip its generation entirely by passing &mut ().
encoders: &'a [(&'a str, &'a Encoder)]A list of recognised encodings for data literals, as pairs of (unescaped) encoding identifier and Encoder references.